# Single Content Sync

A simple way to export/import a node content with all entity references.

## Export content

### Which entity references can be exported?

Here is a current list of supported entity references:

- Taxonomy term
- Node
- Block content
- User
- Media
- Paragraphs

This list can be extended by you, see how to do it below.

### Can I extend exporting of my custom entity type?

Yes! You can implement a new `SingleContentSyncBaseFieldsProcessor` plugin to support your custom entity.

Check a few examples of existing plugins at `src/Plugin/SingleContentSyncBaseFieldsProcessor`.

### Is there any other way I could extend exported entity?

The module would dispatch the `ExportEvent` event before exporting an entity. You can use it to alter the output
before exporting.

## Import content

### Can I extend importing of my custom entity?

In most cases, new entity types would be handled automatically. Similar to exporting, there's an `ImportEvent` which
could be subscribed to alter the imported entity before it's saved.

### Can I import my content on deploy?

Yes! Please use the importer service and hook_update_N or similar to do it.

```php
function example_update_9001() {
  $file_path = \Drupal::service('extension.list.module')
    ->getPath('example') . '/assets/homepage.yml';

  \Drupal::service('single_content_sync.importer')
    ->importFromFile($file_path);
}
```

If you would like to import content from a generated zip file,
use the following code:

```php
function example_update_9001() {
  $file_path = \Drupal::service('extension.list.module')
    ->getPath('example') . '/assets/homepage.zip';

  \Drupal::service('single_content_sync.importer')
    ->importFromZip($file_path);
}
```

## Implementing extra field types

You can implement `SingleContentSyncFieldProcessor` plugin for your custom field type or contrib field types
which aren't supported by the module yet - patches are welcome!

Check a few examples of existing plugins at `src/Plugin/SingleContentSyncFieldProcessor`.

The plugin should include both import and export logic (and it's pretty much straightforward).

## Documentation

Check out the guide to see the module’s overview and the guidelines for using it

https://www.drupal.org/docs/contributed-modules/single-content-sync
